package com.javacodegeeks.dw;

import com.javacodegeeks.dw.persistence.Task;
import com.javacodegeeks.dw.persistence.TaskRepository;
import com.javacodegeeks.dw.web.TaskResource;

import io.dropwizard.Application;
import io.dropwizard.configuration.EnvironmentVariableSubstitutor;
import io.dropwizard.configuration.SubstitutingSourceProvider;
import io.dropwizard.db.DataSourceFactory;
import io.dropwizard.flyway.FlywayBundle;
import io.dropwizard.flyway.FlywayFactory;
import io.dropwizard.hibernate.HibernateBundle;
import io.dropwizard.setup.Bootstrap;
import io.dropwizard.setup.Environment;

public class AppStarter extends Application<AppConfiguration> {
    private final HibernateBundle<AppConfiguration> hibernateBundle = new HibernateBundle<AppConfiguration>(Task.class) {
        @Override
        public DataSourceFactory getDataSourceFactory(AppConfiguration configuration) {
            return configuration.getDataSourceFactory();
        }
    };

    private final FlywayBundle<AppConfiguration> flywayBundle = new FlywayBundle<AppConfiguration>() {
        @Override
        public DataSourceFactory getDataSourceFactory(AppConfiguration configuration) {
            return configuration.getDataSourceFactory();
        }
        
        @Override
        public FlywayFactory getFlywayFactory(AppConfiguration configuration) {
            return configuration.getFlywayFactory();
        }
    };
    
    public static void main(String[] args) throws Exception {
        new AppStarter().run(args);
    }

    @Override
    public String getName() {
        return "dropwizard-webapp";
    }

    @Override
    public void initialize(Bootstrap<AppConfiguration> bootstrap) {
        // Enable variable substitution with environment variables
        bootstrap.setConfigurationSourceProvider(
            new SubstitutingSourceProvider(bootstrap.getConfigurationSourceProvider(),
                new EnvironmentVariableSubstitutor(false))
        );

        bootstrap.addBundle(flywayBundle);
        bootstrap.addBundle(hibernateBundle);
    }

    @Override
    public void run(AppConfiguration configuration, Environment environment) {
        final TaskRepository repository = new TaskRepository(hibernateBundle.getSessionFactory());
        environment.jersey().register(new TaskResource(repository));
    }

}
